package com.gic.haoban.manage.service.service.out.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.haoban.manage.api.dto.ApplicationTemplateDTO;
import com.gic.haoban.manage.api.dto.TemplateEnterpriseRelatedDTO;
import com.gic.haoban.manage.api.service.ApplicationTemplateApiService;
import com.gic.haoban.manage.service.entity.TabHaobanTemplateApplicationRelated;
import com.gic.haoban.manage.service.service.ApplicationTemplateService;
import com.gic.haoban.manage.service.service.TemplateApplicationRelatedService;
import com.gic.haoban.manage.service.service.TemplateEnterpriseRelatedService;

@Service
public class ApplicationTemplateApiServiceImpl implements ApplicationTemplateApiService {

	@Autowired
	private ApplicationTemplateService applicationTemplateService;
	
	@Autowired
	private TemplateEnterpriseRelatedService templateEnterpriseRelatedService;
	
	@Autowired
	private TemplateApplicationRelatedService templateApplicationRelatedService;
	
	@Override
	public ApplicationTemplateDTO selectByTemplateName(String templateName) {
		return applicationTemplateService.selectByTemplateName(templateName);
	}
	
	@Override
	public String insertTemplate(ApplicationTemplateDTO template,String applicationIds) {
		String templateId = applicationTemplateService.insertTemplate(template);
		String[] applicationIdArr = applicationIds.split(",");
		for (String applicationId : applicationIdArr) {
			TabHaobanTemplateApplicationRelated tab  = new TabHaobanTemplateApplicationRelated();
			tab.setTemplateId(templateId);
			tab.setApplicationId(applicationId);
			templateApplicationRelatedService.insert(tab);
		}
		return templateId;
	}

	@Override
	public List<TemplateEnterpriseRelatedDTO> listEnterpriseByTemplateId(String templateId) {
		return templateEnterpriseRelatedService.listEnterpriseByTemplateId(templateId);
	}

	@Override
	public void delTemplate(String templateId) {
		List<TemplateEnterpriseRelatedDTO> list = templateEnterpriseRelatedService.listEnterpriseByTemplateId(templateId);
		if(list != null && !list.isEmpty()){
			return;
		}
		applicationTemplateService.delTemplate(templateId);
		
	}

	@Override
	public void editTemplate(String applicationTemplateId, String applicationTemplateName, String applicationIds) {
		ApplicationTemplateDTO template = applicationTemplateService.selectByTemplateName(applicationTemplateName);
		if(template != null && !template.getApplicationTemplateId().equals(applicationTemplateId)){
			return;
		}
		ApplicationTemplateDTO old = applicationTemplateService.selectByTemplateId(applicationTemplateId);
		old.setApplicationTemplateName(applicationTemplateName);
		
		templateApplicationRelatedService.update(applicationTemplateId,applicationIds);
		applicationTemplateService.editTemplate(old);
		
	}

	@Override
	public List<ApplicationTemplateDTO> listByTemplateName(String applicationTemplateName) {
		return applicationTemplateService.listByTemplateName(applicationTemplateName);
	}

	@Override
	public void addTemplateEnterprise(String applicationTemplateId, String wxEnterpriseIds) {
		String[] wxEnterpriseIdArr = wxEnterpriseIds.split(",");
		for (String wxEnterpriseId : wxEnterpriseIdArr) {
			TemplateEnterpriseRelatedDTO dto = templateEnterpriseRelatedService.selectByWxEnterpriseId(wxEnterpriseId);
			if(dto == null){
				continue;
			}
			dto = new TemplateEnterpriseRelatedDTO();
			dto.setWxEnterpriseId(wxEnterpriseId);
			dto.setApplicationTemplateId(applicationTemplateId);
			templateEnterpriseRelatedService.insert(dto);
		}
	}

	@Override
	public void delTemplateEnterprise(String wxEnterpriseId) {
		TemplateEnterpriseRelatedDTO dto = templateEnterpriseRelatedService.selectByWxEnterpriseId(wxEnterpriseId);
		if(dto != null){
			dto.setStatusFlag(0);
			templateEnterpriseRelatedService.update(dto);
		}
		
	}

}
